]> git.sesse.net Git - stockfish/blobdiff - src/tt.h
Fixed some warnings when using -Weffc++ gcc option
[stockfish] / src / tt.h
index 1c32ddc1872211e0150987d079942d8fef5bf3be..9babce8cdc9f10e14500c1f9c4e5cdc6a071d033 100644 (file)
--- a/src/tt.h
+++ b/src/tt.h
@@ -26,7 +26,7 @@
 ////
 
 #include "depth.h"
-#include "position.h"
+#include "move.h"
 #include "value.h"
 
 
 /// bit 64-79: value
 /// bit 80-95: depth
 /// bit 96-111: static value
/// bit 112-127: king danger value
 ///
 /// the 32 bits of the data field are so defined
 ///
 /// bit  0-16: move
/// bit 17-19: not used
/// bit 20-22: value type
 /// bit 23-31: generation
 
 class TTEntry {
@@ -58,21 +58,21 @@ public:
   void save(uint32_t k, Value v, ValueType t, Depth d, Move m, int g, Value statV, Value kd) {
 
       key32 = k;
-      data = (m & 0x1FFFF) | (t << 20) | (g << 23);
+      data = (m & 0x1FFFF) | (t << 21) | (g << 23);
       value16     = int16_t(v);
       depth16     = int16_t(d);
       staticValue = int16_t(statV);
-      kingDanger  = int16_t(kd);
+      staticValueMargin  = int16_t(kd);
   }
 
   uint32_t key() const { return key32; }
   Depth depth() const { return Depth(depth16); }
   Move move() const { return Move(data & 0x1FFFF); }
   Value value() const { return Value(value16); }
-  ValueType type() const { return ValueType((data >> 20) & 7); }
+  ValueType type() const { return ValueType((data >> 21) & 3); }
   int generation() const { return data >> 23; }
   Value static_value() const { return Value(staticValue); }
-  Value king_danger() const { return Value(kingDanger); }
+  Value static_value_margin() const { return Value(staticValueMargin); }
 
 private:
   uint32_t key32;
@@ -80,17 +80,16 @@ private:
   int16_t value16;
   int16_t depth16;
   int16_t staticValue;
-  int16_t kingDanger;
+  int16_t staticValueMargin;
 };
 
 
-/// This is the number of TTEntry slots for each position
+/// This is the number of TTEntry slots for each cluster
 const int ClusterSize = 4;
 
-/// Each group of ClusterSize number of TTEntry form a TTCluster
-/// that is indexed by a single position key. TTCluster size must
-///  be not bigger then a cache line size, in case it is less then
-/// it should be padded to guarantee always aligned accesses.
+/// TTCluster consists of ClusterSize number of TTEntries.
+/// Size of TTCluster must not be bigger than a cache line size.
+/// In case it is less, it should be padded to guarantee always aligned accesses.
 
 struct TTCluster {
   TTEntry data[ClusterSize];
@@ -98,11 +97,14 @@ struct TTCluster {
 
 
 /// The transposition table class. This is basically just a huge array
-/// containing TTEntry objects, and a few methods for writing new entries
+/// containing TTCluster objects, and a few methods for writing new entries
 /// and reading new ones.
 
 class TranspositionTable {
 
+  TranspositionTable(const TranspositionTable&);
+  TranspositionTable& operator=(const TranspositionTable&);
+
 public:
   TranspositionTable();
   ~TranspositionTable();
@@ -123,8 +125,8 @@ extern TranspositionTable TT;
 
 
 /// TranspositionTable::first_entry returns a pointer to the first
-/// entry of a cluster given a position. The low 32 bits of the key
-/// are used to get the index in the table.
+/// entry of a cluster given a position. The lowest order bits of the key
+/// are used to get the index of the cluster.
 
 inline TTEntry* TranspositionTable::first_entry(const Key posKey) const {
@@ -26,7 +26,7 @@
 /// bit 80-95: depth
 /// bit 96-111: static value
-/// bit 112-127: king danger value
+/// bit 112-127: margin of static value
 ///
 /// the 32 bits of the data field are so defined
@@ -26,7 +26,7 @@
 ///
 /// bit  0-16: move
-/// bit 17-19: not used
-/// bit 20-22: value type
+/// bit 17-20: not used
+/// bit 21-22: value type
 /// bit 23-31: generation
 